==> citrus-spring-integration-3.0.0-sources.jar: com/consol/citrus/model/config/channel/MessageChannelAdapterType.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.3.2 generiert 
// Siehe <a href="https://javaee.github.io/jaxb-v2/">https://javaee.github.io/jaxb-v2/</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2021.07.21 um 10:17:43 AM CEST 
//


package com.consol.citrus.model.config.channel;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * Basic channel endpoint properties.
 * 
 * <p>Java-Klasse für MessageChannelAdapterType complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>
 * &lt;complexType name="MessageChannelAdapterType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
 *       &lt;attribute name="message-channel-template" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="messaging-template" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="channel" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="channel-name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="channel-resolver" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="use-object-messages" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MessageChannelAdapterType")
@XmlSeeAlso({
    ChannelEndpointAdapterModel.class,
    ChannelSyncEndpointModel.class,
    ChannelEndpointModel.class
})
public class MessageChannelAdapterType {

    @XmlAttribute(name = "id")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "message-channel-template")
    protected String messageChannelTemplate;
    @XmlAttribute(name = "messaging-template")
    protected String messagingTemplate;
    @XmlAttribute(name = "channel")
    protected String channel;
    @XmlAttribute(name = "channel-name")
    protected String channelName;
    @XmlAttribute(name = "channel-resolver")
    protected String channelResolver;
    @XmlAttribute(name = "use-object-messages")
    protected Boolean useObjectMessages;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "timeout")
    protected String timeout;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der messageChannelTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageChannelTemplate() {
        return messageChannelTemplate;
    }

    /**
     * Legt den Wert der messageChannelTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageChannelTemplate(String value) {
        this.messageChannelTemplate = value;
    }

    /**
     * Ruft den Wert der messagingTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessagingTemplate() {
        return messagingTemplate;
    }

    /**
     * Legt den Wert der messagingTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessagingTemplate(String value) {
        this.messagingTemplate = value;
    }

    /**
     * Ruft den Wert der channel-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getChannel() {
        return channel;
    }

    /**
     * Legt den Wert der channel-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setChannel(String value) {
        this.channel = value;
    }

    /**
     * Ruft den Wert der channelName-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getChannelName() {
        return channelName;
    }

    /**
     * Legt den Wert der channelName-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setChannelName(String value) {
        this.channelName = value;
    }

    /**
     * Ruft den Wert der channelResolver-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getChannelResolver() {
        return channelResolver;
    }

    /**
     * Legt den Wert der channelResolver-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setChannelResolver(String value) {
        this.channelResolver = value;
    }

    /**
     * Ruft den Wert der useObjectMessages-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isUseObjectMessages() {
        return useObjectMessages;
    }

    /**
     * Legt den Wert der useObjectMessages-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseObjectMessages(Boolean value) {
        this.useObjectMessages = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

}

==> citrus-spring-integration-3.1.1-sources.jar: com/consol/citrus/model/config/channel/MessageChannelAdapterType.java <==
//
// Diese Datei wurde mit der JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.3.2 generiert 
// Siehe <a href="https://javaee.github.io/jaxb-v2/">https://javaee.github.io/jaxb-v2/</a> 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
// Generiert: 2021.12.14 um 11:14:09 AM CET 
//


package com.consol.citrus.model.config.channel;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlID;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * Basic channel endpoint properties.
 * 
 * <p>Java-Klasse für MessageChannelAdapterType complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>
 * &lt;complexType name="MessageChannelAdapterType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;attribute name="id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
 *       &lt;attribute name="message-channel-template" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="messaging-template" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="channel" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="channel-name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="channel-resolver" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="use-object-messages" type="{http://www.w3.org/2001/XMLSchema}boolean" /&gt;
 *       &lt;attribute name="filter-internal-headers" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="timeout" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "MessageChannelAdapterType")
@XmlSeeAlso({
    ChannelEndpointAdapterModel.class,
    ChannelSyncEndpointModel.class,
    ChannelEndpointModel.class
})
public class MessageChannelAdapterType {

    @XmlAttribute(name = "id")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    @XmlID
    @XmlSchemaType(name = "ID")
    protected String id;
    @XmlAttribute(name = "message-channel-template")
    protected String messageChannelTemplate;
    @XmlAttribute(name = "messaging-template")
    protected String messagingTemplate;
    @XmlAttribute(name = "channel")
    protected String channel;
    @XmlAttribute(name = "channel-name")
    protected String channelName;
    @XmlAttribute(name = "channel-resolver")
    protected String channelResolver;
    @XmlAttribute(name = "use-object-messages")
    protected Boolean useObjectMessages;
    @XmlAttribute(name = "filter-internal-headers")
    protected Boolean filterInternalHeaders;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "timeout")
    protected String timeout;

    /**
     * Ruft den Wert der id-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Legt den Wert der id-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setId(String value) {
        this.id = value;
    }

    /**
     * Ruft den Wert der messageChannelTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessageChannelTemplate() {
        return messageChannelTemplate;
    }

    /**
     * Legt den Wert der messageChannelTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessageChannelTemplate(String value) {
        this.messageChannelTemplate = value;
    }

    /**
     * Ruft den Wert der messagingTemplate-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMessagingTemplate() {
        return messagingTemplate;
    }

    /**
     * Legt den Wert der messagingTemplate-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMessagingTemplate(String value) {
        this.messagingTemplate = value;
    }

    /**
     * Ruft den Wert der channel-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getChannel() {
        return channel;
    }

    /**
     * Legt den Wert der channel-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setChannel(String value) {
        this.channel = value;
    }

    /**
     * Ruft den Wert der channelName-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getChannelName() {
        return channelName;
    }

    /**
     * Legt den Wert der channelName-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setChannelName(String value) {
        this.channelName = value;
    }

    /**
     * Ruft den Wert der channelResolver-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getChannelResolver() {
        return channelResolver;
    }

    /**
     * Legt den Wert der channelResolver-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setChannelResolver(String value) {
        this.channelResolver = value;
    }

    /**
     * Ruft den Wert der useObjectMessages-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isUseObjectMessages() {
        return useObjectMessages;
    }

    /**
     * Legt den Wert der useObjectMessages-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUseObjectMessages(Boolean value) {
        this.useObjectMessages = value;
    }

    /**
     * Ruft den Wert der filterInternalHeaders-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFilterInternalHeaders() {
        if (filterInternalHeaders == null) {
            return true;
        } else {
            return filterInternalHeaders;
        }
    }

    /**
     * Legt den Wert der filterInternalHeaders-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFilterInternalHeaders(Boolean value) {
        this.filterInternalHeaders = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der timeout-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTimeout() {
        return timeout;
    }

    /**
     * Legt den Wert der timeout-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTimeout(String value) {
        this.timeout = value;
    }

}
